#
# spec file for package spacewalk-backend
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008-2018 Red Hat, Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rhnroot %{_prefix}/share/rhn
%global rhnconfigdefaults %{rhnroot}/config-defaults
%global rhnconf %{_sysconfdir}/rhn
%global m2crypto m2crypto

%if 0%{?fedora} || 0%{?suse_version} >= 1500 || 0%{?rhel} >= 8
%{!?python3_sitelib: %global python3_sitelib %(%{__python3} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%global python_sitelib %{python3_sitelib}
%global python3rhnroot %{python3_sitelib}/spacewalk
%global pythonrhnroot %{python3_sitelib}/spacewalk
%global build_py3 1
%endif

%define pythonX %{?build_py3:python3}%{!?build_py3:python}

%if 0%{?fedora} || 0%{?rhel} >= 7
%{!?pylint_check: %global pylint_check 0}
%endif

%if 0%{?fedora} || 0%{?rhel}
%global apacheconfd %{_sysconfdir}/httpd/conf.d
%global apache_user apache
%global apache_group apache
%global apache_pkg httpd
%endif

%if 0%{?suse_version}
%{!?pylint_check: %global pylint_check 0}
%global apacheconfd %{_sysconfdir}/apache2/conf.d
%global apache_user wwwrun
%global apache_group www
%global apache_pkg apache2
%global m2crypto %{pythonX}-M2Crypto
%if !0%{?is_opensuse}
%define with_oracle     1
%endif
%endif

%if 0%{?suse_version} >= 1500
%global python_prefix python3
%else
%if  0%{?fedora} >= 28  || 0%{?rhel} >= 8
%global python_prefix python2
%else
%global python_prefix python
%endif
%endif

%{!?python2_sitelib: %global python2_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%global python2rhnroot %{python2_sitelib}/spacewalk
%if !0%{?build_py3}
%global pythonrhnroot %{python_sitelib}/spacewalk
%endif

Name:           spacewalk-backend
Summary:        Common programs needed to be installed on the Spacewalk servers/proxies
License:        GPL-2.0-only
Group:          Applications/Internet
Version:        4.0.31
Release:    3.35.1
Url:            https://github.com/uyuni-project/uyuni
Source0: spacewalk-backend-git-0.7ad116b.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if !0%{?suse_version} || 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

Requires:       %{pythonX}
# /etc/rhn is provided by spacewalk-proxy-common or by spacewalk-config
Requires:       /etc/rhn
%if 0%{?build_py3}
Requires:       python3-%{name}-libs >= %{version}
Requires:       python3-rhnlib >= 2.5.74
Requires:       python3-rpm
%else
Requires:       %{name}-libs >= %{version}
Requires:       python2-rhnlib >= 2.5.74
%if 0%{?suse_version} >= 1500
Requires:       python2-rpm
%else
Requires:       rpm-python
%endif
%if 0%{?suse_version}
Requires:       python-pyliblzma
%else
%if 0%{?rhel}
Requires:       pyliblzma
%endif # if 0{?rhel}
%endif # 0{?suse_version}
%endif # 0{?build_py3}
# for Debian support
Requires:       %{python_prefix}-debian
%if 0%{?pylint_check}
%if 0%{?build_py3}
BuildRequires:  spacewalk-python3-pylint
%else
BuildRequires:  spacewalk-python2-pylint
%endif
%endif
BuildRequires:  /usr/bin/docbook2man
BuildRequires:  /usr/bin/msgfmt
BuildRequires:  docbook-utils
%if 0%{?build_py3}
BuildRequires:  python3-spacewalk-usix
%else
BuildRequires:  python2-spacewalk-usix
%endif
%if 0%{?fedora} || 0%{?rhel} || 0%{?suse_version} > 1310
%if 0%{?build_py3}
BuildRequires:  python3-gzipstream
BuildRequires:  python3-rhn-client-tools
BuildRequires:  python3-rhnlib >= 2.5.74
BuildRequires:  python3-rpm
%else
BuildRequires:  python2-gzipstream
BuildRequires:  python2-rhn-client-tools
BuildRequires:  python2-rhnlib >= 2.5.74
%if 0%{?suse_version} >= 1500
Requires:       python2-rpm
%else
Requires:       rpm-python
%endif
%endif
BuildRequires:  %{python_prefix}-debian

BuildRequires:  %{m2crypto}
%endif
Requires(pre): %{apache_pkg}
Requires:       %{apache_pkg}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif

%if 0%{?suse_version}
Requires:       %{pythonX}-pycurl
%endif

# we don't really want to require this redhat-release, so we protect
# against installations on other releases using conflicts...
Obsoletes:      rhns < 5.3.0
Obsoletes:      rhns-common < 5.3.0
Provides:       rhns = 1:%{version}-%{release}
Provides:       rhns-common = 1:%{version}-%{release}
Obsoletes:      spacewalk-backend-upload-server < 1.2.28
Provides:       spacewalk-backend-upload-server = 1:%{version}-%{release}

%description
Generic program files needed by the Spacewalk server machines.
This package includes the common code required by all servers/proxies.

%package sql
Summary:        Core functions providing SQL connectivity for the Spacewalk backend modules
Group:          Applications/Internet
Requires(pre): %{name} = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Obsoletes:      rhns-sql < 5.3.0
Provides:       rhns-sql = 1:%{version}-%{release}
Requires:       %{name}-sql-virtual = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif

%description sql
This package contains the basic code that provides SQL connectivity for
the Spacewalk backend modules.

%if 0%{?with_oracle}
%package sql-oracle
Summary:        Oracle backend for Spacewalk
Group:          Applications/Internet
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif
Requires:       python(:DBAPI:oracle)
Provides:       %{name}-sql-virtual = %{version}-%{release}

%description sql-oracle
This package contains provides Oracle connectivity for the Spacewalk backend
modules.
%endif

%package sql-postgresql
Summary:        Postgresql backend for Spacewalk
Group:          Applications/Internet
%if 0%{?build_py3}
Requires:       python3-psycopg2 >= 2.0.14-2
Requires:       python3-spacewalk-usix
%else
Requires:       python-psycopg2 >= 2.0.14-2
Requires:       python2-spacewalk-usix
%endif
Provides:       %{name}-sql-virtual = %{version}-%{release}

%description sql-postgresql
This package contains provides PostgreSQL connectivity for the Spacewalk
backend modules.

%package server
Summary:        Basic code that provides Spacewalk Server functionality
Group:          Applications/Internet
Requires(pre): %{name}-sql = %{version}-%{release}
Requires:       %{name}-sql = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-python-pam
Requires:       python3-spacewalk-usix
%else
Requires:       python-python-pam
Requires:       python2-spacewalk-usix
%endif
Requires:       spacewalk-config
Obsoletes:      rhns-server < 5.3.0
Provides:       rhns-server = 1:%{version}-%{release}

#this exists only on rhel5 and rhel6
Conflicts:      python-sgmlop
# cobbler-web is known to break our configuration
Conflicts:      cobbler-web

%if 0%{?build_py3}
Requires:       apache2-mod_wsgi-python3
%else
Requires:       mod_wsgi
%endif

%description server
This package contains the basic code that provides server/backend
functionality for a variety of XML-RPC receivers. The architecture is
modular so that you can plug/install additional modules for XML-RPC
receivers and get them enabled automatically.

%package xmlrpc
Summary:        Handler for /XMLRPC
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-rpm
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%if 0%{?suse_version} >= 1500
Requires:       python2-rpm
%else
Requires:       rpm-python
%endif
%endif
Obsoletes:      rhns-server-xmlrpc < 5.3.0
Obsoletes:      rhns-xmlrpc < 5.3.0
Provides:       rhns-server-xmlrpc = 1:%{version}-%{release}
Provides:       rhns-xmlrpc = 1:%{version}-%{release}

%description xmlrpc
These are the files required for running the /XMLRPC handler, which
provide the basic support for the registration client (rhn_register)
and the up2date clients.

%package applet
Summary:        Handler for /APPLET
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif
Obsoletes:      rhns-applet < 5.3.0
Provides:       rhns-applet = 1:%{version}-%{release}

%description applet
These are the files required for running the /APPLET handler, which
provides the functions for the Spacewalk applet.

%package app
Summary:        Handler for /APP
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif
Obsoletes:      rhns-app < 5.3.0
Obsoletes:      rhns-server-app < 5.3.0
Provides:       rhns-app = 1:%{version}-%{release}
Provides:       rhns-server-app = 1:%{version}-%{release}
Obsoletes:      spacewalk-backend-xp < 1.8.38
Provides:       spacewalk-backend-xp = %{version}-%{release}
Obsoletes:      rhns-server-xp < 5.3.0
Obsoletes:      rhns-xp < 5.3.0
Provides:       rhns-server-xp = 1:%{version}-%{release}
Provides:       rhns-xp = 1:%{version}-%{release}

%description app
These are the files required for running the /APP handler.
Calls to /APP are used by internal maintenance tools (rhnpush).

%package iss
Summary:        Handler for /SAT
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
Obsoletes:      rhns-sat < 5.3.0
Provides:       rhns-sat = 1:%{version}-%{release}

%description iss
%{name} contains the basic code that provides server/backend
functionality for a variety of XML-RPC receivers. The architecture is
modular so that you can plug/install additional modules for XML-RPC
receivers and get them enabled automatically.

This package contains /SAT handler, which provide Inter Spacewalk Sync
capability.

%package iss-export
Summary:        Listener for the Server XML dumper
Group:          Applications/Internet
Requires:       %{name}-xml-export-libs = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-rpm
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%if 0%{?suse_version} >= 1500
Requires:       python2-rpm
%else
Requires:       rpm-python
%endif
%endif

%description iss-export
%{name} contains the basic code that provides server/backend
functionality for a variety of XML-RPC receivers. The architecture is
modular so that you can plug/install additional modules for XML-RPC
receivers and get them enabled automatically.

This package contains listener for the Server XML dumper.

%package libs
Summary:        Spacewalk server and client tools libraries
Group:          Applications/Internet
Requires:       python
%if 0%{?suse_version}
BuildRequires:  python-devel
%else
BuildRequires:  python2-devel
Conflicts:      %{name} < 1.7.0
%endif
Requires:       python2-spacewalk-usix

%description libs
Libraries required by both Spacewalk server and Spacewalk client tools.

%if 0%{?build_py3}
%package -n python3-%{name}-libs
Summary:        Spacewalk client tools libraries for python3
Group:          Applications/Internet
BuildRequires:  python3-devel
Conflicts:      %{name} < 1.7.0
%if 0%{?suse_version}
Requires:       python3-base
%else
Requires:       python3-libs
%endif
Requires:       python3-spacewalk-usix

%description -n python3-%{name}-libs
Libraries required by Spacewalk client tools on Fedora 23.

%endif

%package config-files-common
Summary:        Common files for the Configuration Management project
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif
Obsoletes:      rhns-config-files-common < 5.3.0
Provides:       rhns-config-files-common = 1:%{version}-%{release}

%description config-files-common
Common files required by the Configuration Management project

%package config-files
Summary:        Handler for /CONFIG-MANAGEMENT
Group:          Applications/Internet
Requires:       %{name}-config-files-common = %{version}-%{release}
Obsoletes:      rhns-config-files < 5.3.0
Provides:       rhns-config-files = 1:%{version}-%{release}

%description config-files
This package contains the server-side code for configuration management.

%package config-files-tool
Summary:        Handler for /CONFIG-MANAGEMENT-TOOL
Group:          Applications/Internet
Requires:       %{name}-config-files-common = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif
Obsoletes:      rhns-config-files-tool < 5.3.0
Provides:       rhns-config-files-tool = 1:%{version}-%{release}

%description config-files-tool
This package contains the server-side code for configuration management tool.

%package package-push-server
Summary:        Listener for rhnpush (non-XMLRPC version)
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
Obsoletes:      rhns-package-push-server < 5.3.0
Provides:       rhns-package-push-server = 1:%{version}-%{release}

%description package-push-server
Listener for rhnpush (non-XMLRPC version)

%package tools
Summary:        Spacewalk Services Tools
Group:          Applications/Internet
Requires:       %{name}
Requires:       %{name}-app = %{version}-%{release}
Requires:       %{name}-xmlrpc = %{version}-%{release}
%if 0%{?suse_version} >= 1210
Requires:       systemd
BuildRequires:  systemd
%{?systemd_requires}
%endif

%if 0%{?build_py3}
Requires:       python3-gzipstream
Requires:       python3-python-dateutil
Requires:       python3-rhn-client-tools
Requires:       python3-solv
Requires:       python3-urlgrabber
%else
Requires:       python-configparser
Requires:       python-dateutil
Requires:       python-solv
Requires:       python2-gzipstream
Requires:       python2-rhn-client-tools
Requires:       python2-urlgrabber
%if 0%{?suse_version}
Requires:       python-pyliblzma
%else
%if 0%{?fedora} || 0%{?rhel} > 6
Requires:       pyliblzma
%endif # 0{?fedora} || 0{?rhel} > 6
%endif # 0{?suse_version}
%endif # 0{?build_py3}
Requires:       spacewalk-admin >= 0.1.1-0
Requires:       spacewalk-certs-tools
%if 0%{?suse_version}
Requires:       apache2-prefork
Requires:       susemanager-tools
%endif
%if 0%{?fedora} || 0%{?rhel}
Requires:       mod_ssl
Requires:       python2-devel
%endif
Requires:       %{name}-xml-export-libs
Requires:       cobbler >= 2.0.0
%if 0%{?fedora} >= 22
Recommends:     cobbler20
%endif
Requires:       %{m2crypto}
Requires:       %{pythonX}-requests
%if 0%{?build_py3}
Requires:       python3-rhnlib  >= 2.5.57
Requires:       python3-spacewalk-usix
%else
Requires:       python2-rhnlib  >= 2.5.57
Requires:       python2-spacewalk-usix
%endif
%if 0%{?fedora} || 0%{?rhel}
BuildRequires:  python-requests
%endif
Obsoletes:      rhns-satellite-tools < 5.3.0
Obsoletes:      spacewalk-backend-satellite-tools <= 0.2.7
Provides:       rhns-satellite-tools = 1:%{version}-%{release}
Provides:       spacewalk-backend-satellite-tools = %{version}-%{release}

%description tools
Various utilities for the Spacewalk Server.

%package xml-export-libs
Summary:        Spacewalk XML data exporter
Group:          Applications/Internet
Requires:       %{name}-server = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-spacewalk-usix
%else
Requires:       python2-spacewalk-usix
%endif
Obsoletes:      rhns-xml-export-libs < 5.3.0
Provides:       rhns-xml-export-libs = 1:%{version}-%{release}

%description xml-export-libs
Libraries required by various exporting tools

%package cdn
Summary:        CDN tools
Group:          Applications/Internet
Requires:       %{m2crypto}
Requires:       %{name}-server = %{version}-%{release}
%if 0%{?build_py3}
Requires:       python3-argparse
Requires:       python3-spacewalk-usix
%else
Requires:       python-argparse
Requires:       python2-spacewalk-usix
%endif
Requires:       subscription-manager

%description cdn
Tools for syncing content from Red Hat CDN

%prep
%setup -q -n spacewalk-backend-git-0.7ad116b

%build
make -f Makefile.backend all PYTHON_BIN=%{pythonX}

# Fixing shebang for Python 3
%if 0%{?build_py3}
for i in `find . -type f`;
do
	sed -i '1s=^#!/usr/bin/\(python\|env python\)[0-9.]*=#!/usr/bin/python3=' $i;
done
%endif

%install
install -d $RPM_BUILD_ROOT%{rhnroot}
install -d $RPM_BUILD_ROOT%{pythonrhnroot}
install -d $RPM_BUILD_ROOT%{pythonrhnroot}/common
install -d $RPM_BUILD_ROOT%{rhnconf}
install -d $RPM_BUILD_ROOT/%{_prefix}/lib/susemanager/bin/
%if 0%{?suse_version} >= 1210
install -d $RPM_BUILD_ROOT/%{_unitdir}
%endif

make -f Makefile.backend install PREFIX=$RPM_BUILD_ROOT \
    MANDIR=%{_mandir} APACHECONFDIR=%{apacheconfd} PYTHON_BIN=%{pythonX}
%if !0%{?with_oracle}
rm -f $RPM_BUILD_ROOT%{pythonrhnroot}/server/rhnSQL/driver_cx_Oracle.py*
%endif

%if 0%{?build_py3}
install -d $RPM_BUILD_ROOT%{pythonrhnroot}/common
install -d $RPM_BUILD_ROOT%{python2rhnroot}/common
cp $RPM_BUILD_ROOT%{pythonrhnroot}/__init__.py \
    $RPM_BUILD_ROOT%{python2rhnroot}/
cp $RPM_BUILD_ROOT%{pythonrhnroot}/common/__init__.py \
    $RPM_BUILD_ROOT%{python2rhnroot}/common
cp $RPM_BUILD_ROOT%{pythonrhnroot}/common/{checksum.py,cli.py,rhn_deb.py,rhn_mpm.py,rhn_pkg.py,rhn_rpm.py,stringutils.py,fileutils.py,rhnLib.py,timezone_utils.py} \
    $RPM_BUILD_ROOT%{python2rhnroot}/common
%endif

export PYTHON_MODULE_NAME=%{name}
export PYTHON_MODULE_VERSION=%{version}

# remove all unsupported translations
cd $RPM_BUILD_ROOT
for d in usr/share/locale/*; do
  if [ ! -d "/$d" ]; then
    rm -rfv "./$d"
  fi
done
cd -
ln -s satellite-sync $RPM_BUILD_ROOT/usr/bin/mgr-inter-sync
ln -s satellite-sync.8.gz $RPM_BUILD_ROOT/usr/share/man/man8/mgr-inter-sync.8.gz
ln -s rhn-satellite-exporter $RPM_BUILD_ROOT/usr/bin/mgr-exporter

install -m 644 rhn-conf/signing.cnf $RPM_BUILD_ROOT%{rhnconf}/signing.conf

%if 0%{?suse_version} >= 1210
install -m 644 satellite_tools/spacewalk-diskcheck.service $RPM_BUILD_ROOT/%{_unitdir}
install -m 644 satellite_tools/spacewalk-diskcheck.timer $RPM_BUILD_ROOT/%{_unitdir}
%endif

%find_lang %{name}-server

%if 0%{?is_opensuse}
sed -i 's/^product_name.*/product_name = Uyuni/' $RPM_BUILD_ROOT%{rhnconfigdefaults}/rhn.conf
%endif
%if 0%{?fedora} || 0%{?rhel} > 6
sed -i 's/#LOGROTATE-3.8#//' $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/spacewalk-backend-*
sed -i 's/#DOCUMENTROOT#/\/var\/www\/html/' $RPM_BUILD_ROOT%{rhnconfigdefaults}/rhn.conf
%endif
%if 0%{?suse_version}
sed -i 's/#LOGROTATE-3.8#.*/    su root www/' $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/spacewalk-backend-*
sed -i 's/#DOCUMENTROOT#/\/srv\/www\/htdocs/' $RPM_BUILD_ROOT%{rhnconfigdefaults}/rhn.conf
%if !0%{?build_py3}
pushd $RPM_BUILD_ROOT
find -name '*.py' -print0 | xargs -0 python %py_libdir/py_compile.py
popd
%endif

%if 0%{?build_py3}
%py3_compile -O %{buildroot}/%{pythonrhnroot}
%py_compile -O %{buildroot}/%{python2rhnroot}
rm -f $RPM_BUILD_ROOT%{python2rhnroot}/__init__.py*
rm -f $RPM_BUILD_ROOT%{python2rhnroot}/common/__init__.py*
%endif
%endif

install -m 755 satellite_tools/mgr-update-pkg-extra-tags $RPM_BUILD_ROOT%{_prefix}/lib/susemanager/bin/

%check
# Copy spacewalk-usix python files to allow unit tests to run
cp %{pythonrhnroot}/common/usix* $RPM_BUILD_ROOT%{pythonrhnroot}/common/
make -f Makefile.backend PYTHONPATH=$RPM_BUILD_ROOT%{python_sitelib} PYTHON_BIN=%{pythonX} test

%if 0%{?pylint_check}
# check coding style
export PYTHONPATH=$RPM_BUILD_ROOT%{pythonrhnroot}:/usr/lib/rhn:/usr/share/rhn
spacewalk-%{pythonX} $RPM_BUILD_ROOT%{pythonrhnroot}/common \
                     $RPM_BUILD_ROOT%{pythonrhnroot}/satellite_exporter \
                     $RPM_BUILD_ROOT%{pythonrhnroot}/satellite_tools \
                     $RPM_BUILD_ROOT%{pythonrhnroot}/cdn_tools \
                     $RPM_BUILD_ROOT%{pythonrhnroot}/upload_server \
                     $RPM_BUILD_ROOT%{pythonrhnroot}/wsgi

%if 0%{?build_py3}
export PYTHONPATH=$RPM_BUILD_ROOT%{python2rhnroot}:/usr/lib/rhn:/usr/share/rhn
spacewalk-python2 $RPM_BUILD_ROOT%{python2rhnroot}/common \
                  $RPM_BUILD_ROOT%{python2rhnroot}/satellite_exporter \
                  $RPM_BUILD_ROOT%{python2rhnroot}/satellite_tools \
                  $RPM_BUILD_ROOT%{python2rhnroot}/cdn_tools \
                  $RPM_BUILD_ROOT%{python2rhnroot}/upload_server \
                  $RPM_BUILD_ROOT%{python2rhnroot}/wsgi
%endif
%endif

# prevent file conflict with spacewalk-usix
rm -f $RPM_BUILD_ROOT%{pythonrhnroot}/__init__.py*
rm -f $RPM_BUILD_ROOT%{pythonrhnroot}/common/__init__.py*

# Remove spacewalk-usix python files used for running unit-tests
rm -f $RPM_BUILD_ROOT%{pythonrhnroot}/common/usix.py*
%if 0%{?build_py3}
rm -f $RPM_BUILD_ROOT%{pythonrhnroot}/common/__pycache__/usix*
%endif

%if !0%{?build_py3}
if [ -x %py_libdir/py_compile.py ]; then
    pushd %{buildroot}
    find -name '*.py' -print0 | xargs -0 python %py_libdir/py_compile.py
    popd
fi
%endif

%pre server
OLD_SECRET_FILE=%{_var}/www/rhns/server/secret/rhnSecret.py
if [ -f $OLD_SECRET_FILE ]; then
    install -d -m 750 -o root -g %{apache_group} %{rhnconf}
    mv ${OLD_SECRET_FILE}*  %{rhnconf}
fi

%post server
%if 0%{?suse_version}
sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES wsgi
%endif
if [ ! -e %{rhnconf}/rhn.conf ]; then
    exit 0
fi

%if 0%{?suse_version} >= 1210
%pre tools
%service_add_pre spacewalk-diskcheck.service spacewalk-diskcheck.timer

%post tools
%service_add_post spacewalk-diskcheck.service spacewalk-diskcheck.timer

%preun tools
%service_del_preun spacewalk-diskcheck.service spacewalk-diskcheck.timer

%postun tools
%service_del_postun spacewalk-diskcheck.service spacewalk-diskcheck.timer
%endif

# Is secret key in our config file?
regex="^[[:space:]]*(server\.|)secret_key[[:space:]]*=.*$"

if grep -E -i $regex %{rhnconf}/rhn.conf > /dev/null 2>&1 ; then
    # secret key already there
    rm -f %{rhnconf}/rhnSecret.py*
    exit 0
fi

# Generate a secret key if old one is not present
if [ -f %{rhnconf}/rhnSecret.py ]; then
    secret_key=$(PYTHONPATH=%{rhnconf} %{__python} -c \
        "from rhnSecret import SECRET_KEY; print SECRET_KEY")
else
    secret_key=$(dd if=/dev/urandom bs=1024 count=1 2>/dev/null | sha1sum - |
        awk '{print $1}')
fi

echo "server.secret_key = $secret_key" >> %{rhnconf}/rhn.conf
rm -f %{rhnconf}/rhnSecret.py*

%files
%defattr(-,root,root)
%doc LICENSE
%dir %{pythonrhnroot}
%dir %{_prefix}/lib/susemanager
%dir %{_prefix}/lib/susemanager/bin
%{pythonrhnroot}/common/suseLib.py*
%{pythonrhnroot}/common/apache.py*
%{pythonrhnroot}/common/byterange.py*
%{pythonrhnroot}/common/rhnApache.py*
%{pythonrhnroot}/common/rhnCache.py*
%{pythonrhnroot}/common/rhnConfig.py*
%{pythonrhnroot}/common/rhnException.py*
%{pythonrhnroot}/common/rhnFlags.py*
%{pythonrhnroot}/common/rhnLog.py*
%{pythonrhnroot}/common/rhnMail.py*
%{pythonrhnroot}/common/rhnTB.py*
%{pythonrhnroot}/common/rhnRepository.py*
%{pythonrhnroot}/common/rhnTranslate.py*
%{pythonrhnroot}/common/RPC_Base.py*
%attr(770,root,%{apache_group}) %dir %{_var}/log/rhn
# Workaround for strict-whitespace-enforcement in httpd
%attr(644,root,%{apache_group}) %config %{apacheconfd}/aa-spacewalk-server.conf
# config files
%attr(755,root,%{apache_group}) %dir %{rhnconfigdefaults}
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn.conf
%attr(755,root,root) %{_bindir}/spacewalk-cfg-get
%{_mandir}/man8/spacewalk-cfg-get.8.gz
# wsgi stuff
%dir %{rhnroot}/wsgi
%{rhnroot}/wsgi/__init__.py*
%{rhnroot}/wsgi/wsgiHandler.py*
%{rhnroot}/wsgi/wsgiRequest.py*
%if 0%{?suse_version}
%dir %{rhnroot}
%endif
%if 0%{?build_py3}
%dir %{pythonrhnroot}/__pycache__/
%{pythonrhnroot}/__pycache__/*
%{pythonrhnroot}/common/__pycache__/*
%endif

%files sql
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
# Need __init__ = share it with rhns-server
%dir %{pythonrhnroot}/server
%{pythonrhnroot}/server/__init__.py*
%{rhnroot}/server/__init__.py*
%dir %{pythonrhnroot}/server/rhnSQL
%{pythonrhnroot}/server/rhnSQL/const.py*
%{pythonrhnroot}/server/rhnSQL/dbi.py*
%{pythonrhnroot}/server/rhnSQL/__init__.py*
%{pythonrhnroot}/server/rhnSQL/sql_*.py*
%if 0%{?build_py3}
%dir %{pythonrhnroot}/server/__pycache__/
%dir %{pythonrhnroot}/server/rhnSQL/__pycache__/
%{pythonrhnroot}/server/__pycache__/*
%{pythonrhnroot}/server/rhnSQL/__pycache__/*
%endif

%if 0%{?with_oracle}
%files sql-oracle
%defattr(-,root,root)
%doc LICENSE
%{pythonrhnroot}/server/rhnSQL/driver_cx_Oracle.py*
%endif

%files sql-postgresql
%defattr(-,root,root)
%doc LICENSE
%{pythonrhnroot}/server/rhnSQL/driver_postgresql.py*

%files server -f %{name}-server.lang
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
# modules
%{pythonrhnroot}/server/apacheAuth.py*
%{pythonrhnroot}/server/apacheHandler.py*
%{pythonrhnroot}/server/apacheRequest.py*
%{pythonrhnroot}/server/apacheServer.py*
%{pythonrhnroot}/server/apacheUploadServer.py*
%{pythonrhnroot}/server/rhnAction.py*
%{pythonrhnroot}/server/rhnAuthPAM.py*
%{pythonrhnroot}/server/rhnCapability.py*
%{pythonrhnroot}/server/rhnChannel.py*
%{pythonrhnroot}/server/rhnDependency.py*
%{pythonrhnroot}/server/rhnPackage.py*
%{pythonrhnroot}/server/rhnPackageUpload.py*
%{pythonrhnroot}/server/basePackageUpload.py*
%{pythonrhnroot}/server/rhnHandler.py*
%{pythonrhnroot}/server/rhnImport.py*
%{pythonrhnroot}/server/rhnLib.py*
%{pythonrhnroot}/server/rhnMapping.py*
%{pythonrhnroot}/server/rhnRepository.py*
%{pythonrhnroot}/server/rhnSession.py*
%{pythonrhnroot}/server/rhnUser.py*
%{pythonrhnroot}/server/rhnVirtualization.py*
%{pythonrhnroot}/server/taskomatic.py*
%{pythonrhnroot}/server/suseEula.py*
%dir %{pythonrhnroot}/server/rhnServer
%{pythonrhnroot}/server/rhnServer/*
%dir %{pythonrhnroot}/server/importlib
%{pythonrhnroot}/server/importlib/__init__.py*
%{pythonrhnroot}/server/importlib/archImport.py*
%{pythonrhnroot}/server/importlib/backend.py*
%{pythonrhnroot}/server/importlib/backendLib.py*
%{pythonrhnroot}/server/importlib/backendOracle.py*
%{pythonrhnroot}/server/importlib/backend_checker.py*
%{pythonrhnroot}/server/importlib/channelImport.py*
%{pythonrhnroot}/server/importlib/debPackage.py*
%{pythonrhnroot}/server/importlib/errataCache.py*
%{pythonrhnroot}/server/importlib/errataImport.py*
%{pythonrhnroot}/server/importlib/headerSource.py*
%{pythonrhnroot}/server/importlib/importLib.py*
%{pythonrhnroot}/server/importlib/kickstartImport.py*
%{pythonrhnroot}/server/importlib/mpmSource.py*
%{pythonrhnroot}/server/importlib/packageImport.py*
%{pythonrhnroot}/server/importlib/packageUpload.py*
%{pythonrhnroot}/server/importlib/productNamesImport.py*
%{pythonrhnroot}/server/importlib/userAuth.py*
%{pythonrhnroot}/server/importlib/orgImport.py*
%{pythonrhnroot}/server/importlib/contentSourcesImport.py*
%{pythonrhnroot}/server/importlib/supportInformationImport.py*
%{pythonrhnroot}/server/importlib/suseProductsImport.py*
%if 0%{?build_py3}
%dir %{pythonrhnroot}/server/importlib/__pycache__/
%{pythonrhnroot}/server/importlib/__pycache__/*
%endif
%{rhnroot}/server/handlers/__init__.py*

# Repomd stuff
%dir %{pythonrhnroot}/server/repomd
%{pythonrhnroot}/server/repomd/__init__.py*
%{pythonrhnroot}/server/repomd/domain.py*
%{pythonrhnroot}/server/repomd/mapper.py*
%{pythonrhnroot}/server/repomd/repository.py*
%{pythonrhnroot}/server/repomd/view.py*
%if 0%{?build_py3}
%dir %{pythonrhnroot}/server/repomd/__pycache__/
%{pythonrhnroot}/server/repomd/__pycache__/*
%endif

# the cache
%attr(755,%{apache_user},%{apache_group}) %dir %{_var}/cache/rhn
%attr(755,root,root) %dir %{_var}/cache/rhn/satsync
# config files
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server.conf

# main httpd config
%attr(644,root,%{apache_group}) %config %{apacheconfd}/zz-spacewalk-server.conf

# wsgi stuff
%attr(644,root,%{apache_group}) %config %{apacheconfd}/zz-spacewalk-server-wsgi.conf
%{rhnroot}/wsgi/app.py*
%{rhnroot}/wsgi/applet.py*
%{rhnroot}/wsgi/config.py*
%{rhnroot}/wsgi/config_tool.py*
%{rhnroot}/wsgi/package_push.py*
%{rhnroot}/wsgi/sat.py*
%{rhnroot}/wsgi/sat_dump.py*
%{rhnroot}/wsgi/xmlrpc.py*

# logs and other stuff
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-server

%if 0%{?suse_version}
%dir %{rhnroot}/server
%dir %{rhnroot}/server/handlers
%endif

%files xmlrpc
%defattr(-,root,root)
%doc LICENSE
%dir %{rhnroot}/server/handlers/xmlrpc
%{rhnroot}/server/handlers/xmlrpc/*
%dir %{pythonrhnroot}/server/action
%{pythonrhnroot}/server/action/*
%dir %{pythonrhnroot}/server/action_extra_data
%{pythonrhnroot}/server/action_extra_data/*
%{pythonrhnroot}/server/auditlog.py*
# config files
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_xmlrpc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-xmlrpc
%if 0%{?suse_version}
%dir %{rhnroot}/server
%dir %{rhnroot}/server/handlers
%endif

%files applet
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
%dir %{rhnroot}/server/handlers/applet
%{rhnroot}/server/handlers/applet/*
# config files
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_applet.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-applet

%files app
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
%dir %{rhnroot}/server/handlers/app
%{rhnroot}/server/handlers/app/*
# config files
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_app.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-app

%files iss
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
%dir %{rhnroot}/server/handlers/sat
%{rhnroot}/server/handlers/sat/*
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-iss

%files iss-export
%defattr(-,root,root)
%doc LICENSE
%dir %{pythonrhnroot}/satellite_exporter
%{pythonrhnroot}/satellite_exporter/__init__.py*
%{pythonrhnroot}/satellite_exporter/satexport.py*

%dir %{rhnroot}/satellite_exporter
%dir %{rhnroot}/satellite_exporter/handlers
%{rhnroot}/satellite_exporter/__init__.py*
%{rhnroot}/satellite_exporter/handlers/__init__.py*
%{rhnroot}/satellite_exporter/handlers/non_auth_dumper.py*
%if 0%{?build_py3}
%dir %{pythonrhnroot}/satellite_exporter/__pycache__/
%{pythonrhnroot}/satellite_exporter/__pycache__/*
%endif
# config files
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-iss-export

%files libs
%defattr(-,root,root)
%doc LICENSE
%if 0%{?build_py3}
%dir %{python2rhnroot}
%dir %{python2rhnroot}/common
%endif
%{python2rhnroot}/common/checksum.py*
%{python2rhnroot}/common/cli.py*
%{python2rhnroot}/common/fileutils.py*
%{python2rhnroot}/common/rhn_deb.py*
%{python2rhnroot}/common/rhn_mpm.py*
%{python2rhnroot}/common/rhn_pkg.py*
%{python2rhnroot}/common/rhn_rpm.py*
%{python2rhnroot}/common/stringutils.py*
%{python2rhnroot}/common/rhnLib.py*
%{python2rhnroot}/common/timezone_utils.py*

%if 0%{?build_py3}
%files -n python3-%{name}-libs
%defattr(-,root,root)
%doc LICENSE
%dir %{python3rhnroot}/common
%{python3rhnroot}/common/checksum.py
%{python3rhnroot}/common/cli.py
%{python3rhnroot}/common/fileutils.py
%{python3rhnroot}/common/rhn_deb.py
%{python3rhnroot}/common/rhn_mpm.py
%{python3rhnroot}/common/rhn_pkg.py
%{python3rhnroot}/common/rhn_rpm.py
%{python3rhnroot}/common/stringutils.py
%{python3rhnroot}/common/rhnLib.py*
%{python3rhnroot}/common/timezone_utils.py*
%dir %{python3rhnroot}/common/__pycache__
%{python3rhnroot}/common/__pycache__/checksum.*
%{python3rhnroot}/common/__pycache__/cli.*
%{python3rhnroot}/common/__pycache__/fileutils.*
%{python3rhnroot}/common/__pycache__/rhn_deb.*
%{python3rhnroot}/common/__pycache__/rhn_mpm.*
%{python3rhnroot}/common/__pycache__/rhn_pkg.*
%{python3rhnroot}/common/__pycache__/rhn_rpm.*
%{python3rhnroot}/common/__pycache__/stringutils.*
%{python3rhnroot}/common/__pycache__/rhnLib.*
%{python3rhnroot}/common/__pycache__/timezone_utils.*
%endif

%files config-files-common
%defattr(-,root,root)
%doc LICENSE
%{pythonrhnroot}/server/configFilesHandler.py*
%dir %{pythonrhnroot}/server/config_common
%{pythonrhnroot}/server/config_common/*

%files config-files
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
%dir %{rhnroot}/server/handlers/config
%{rhnroot}/server/handlers/config/*
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_config-management.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-config-files

%files config-files-tool
%defattr(-,root,root)
%doc LICENSE
%if 0%{?suse_version}
%dir %{rhnroot}/server
%endif
%dir %{rhnroot}/server/handlers/config_mgmt
%{rhnroot}/server/handlers/config_mgmt/*
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_config-management-tool.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-config-files-tool

%files package-push-server
%defattr(-,root,root)
%doc LICENSE
%dir %{rhnroot}/upload_server
%{rhnroot}/upload_server/__init__.py*
%dir %{rhnroot}/upload_server/handlers
%{rhnroot}/upload_server/handlers/__init__.py*
%{rhnroot}/upload_server/handlers/package_push
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_upload.conf
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_upload_package-push.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-package-push-server

%files tools
%defattr(-,root,root)
%doc LICENSE
%doc README.ULN
%attr(0750,root,%{apache_group}) %dir %{rhnconf}
%attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_satellite.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-tools
%config(noreplace) %{rhnconf}/signing.conf
%attr(755,root,root) %{_bindir}/rhn-charsets
%attr(755,root,root) %{_bindir}/rhn-satellite-activate
%attr(755,root,root) %{_bindir}/rhn-schema-version
%attr(755,root,root) %{_bindir}/rhn-ssl-dbstore
%attr(755,root,root) %{_bindir}/satellite-sync
%attr(755,root,root) %{_bindir}/mgr-inter-sync
%attr(755,root,root) %{_bindir}/mgr-exporter
%attr(755,root,root) %{_bindir}/spacewalk-debug
%attr(755,root,root) %{_bindir}/rhn-satellite-exporter
%attr(755,root,root) %{_bindir}/update-packages
%attr(755,root,root) %{_bindir}/spacewalk-repo-sync
%attr(755,root,root) %{_bindir}/rhn-db-stats
%attr(755,root,root) %{_bindir}/rhn-schema-stats
%attr(755,root,root) %{_bindir}/satpasswd
%attr(755,root,root) %{_bindir}/satwho
%attr(755,root,root) %{_bindir}/spacewalk-remove-channel*
%attr(755,root,root) %{_bindir}/spacewalk-update-signatures
%attr(755,root,root) %{_bindir}/spacewalk-data-fsck
%attr(755,root,root) %{_bindir}/spacewalk-fips-tool
%attr(755,root,root) %{_bindir}/mgr-sign-metadata
%attr(755,root,root) %{_bindir}/mgr-sign-metadata-ctl
%attr(755,root,root) %{_prefix}/lib/susemanager/bin/mgr-update-pkg-extra-tags
%attr(755,root,root) %{_bindir}/spacewalk-diskcheck
%{pythonrhnroot}/satellite_tools/contentRemove.py*
%{pythonrhnroot}/satellite_tools/SequenceServer.py*
%{pythonrhnroot}/satellite_tools/messages.py*
%{pythonrhnroot}/satellite_tools/progress_bar.py*
%{pythonrhnroot}/satellite_tools/req_channels.py*
%{pythonrhnroot}/satellite_tools/satsync.py*
%{pythonrhnroot}/satellite_tools/satCerts.py*
%{pythonrhnroot}/satellite_tools/satComputePkgHeaders.py*
%{pythonrhnroot}/satellite_tools/syncCache.py*
%{pythonrhnroot}/satellite_tools/sync_handlers.py*
%{pythonrhnroot}/satellite_tools/rhn_satellite_activate.py*
%{pythonrhnroot}/satellite_tools/rhn_ssl_dbstore.py*
%{pythonrhnroot}/satellite_tools/xmlWireSource.py*
%{pythonrhnroot}/satellite_tools/updatePackages.py*
%{pythonrhnroot}/satellite_tools/reposync.py*
%{pythonrhnroot}/satellite_tools/constants.py*
%{pythonrhnroot}/satellite_tools/download.py*
%dir %{pythonrhnroot}/satellite_tools/disk_dumper
%{pythonrhnroot}/satellite_tools/disk_dumper/__init__.py*
%{pythonrhnroot}/satellite_tools/disk_dumper/iss.py*
%{pythonrhnroot}/satellite_tools/disk_dumper/iss_ui.py*
%{pythonrhnroot}/satellite_tools/disk_dumper/iss_isos.py*
%{pythonrhnroot}/satellite_tools/disk_dumper/iss_actions.py*
%{pythonrhnroot}/satellite_tools/disk_dumper/dumper.py*
%{pythonrhnroot}/satellite_tools/disk_dumper/string_buffer.py*
%dir %{pythonrhnroot}/satellite_tools/repo_plugins
%attr(755,root,%{apache_group}) %dir %{_var}/log/rhn/reposync
%{pythonrhnroot}/satellite_tools/repo_plugins/__init__.py*
%{pythonrhnroot}/satellite_tools/repo_plugins/yum_src.py*
%{pythonrhnroot}/satellite_tools/repo_plugins/uln_src.py*
%{pythonrhnroot}/satellite_tools/repo_plugins/deb_src.py*
%if 0%{?build_py3}
%dir %{pythonrhnroot}/satellite_tools/__pycache__/
%dir %{pythonrhnroot}/satellite_tools/disk_dumper/__pycache__/
%dir %{pythonrhnroot}/satellite_tools/repo_plugins/__pycache__/
%{pythonrhnroot}/satellite_tools/__pycache__/*
%{pythonrhnroot}/satellite_tools/disk_dumper/__pycache__/*
%{pythonrhnroot}/satellite_tools/repo_plugins/__pycache__/*
%endif
%config %attr(644,root,%{apache_group}) %{rhnconfigdefaults}/rhn_server_iss.conf
%{_mandir}/man8/rhn-satellite-exporter.8*
%{_mandir}/man8/rhn-charsets.8*
%{_mandir}/man8/rhn-satellite-activate.8*
%{_mandir}/man8/rhn-schema-version.8*
%{_mandir}/man8/rhn-ssl-dbstore.8*
%{_mandir}/man8/rhn-db-stats.8*
%{_mandir}/man8/rhn-schema-stats.8*
%{_mandir}/man8/satellite-sync.8*
%{_mandir}/man8/mgr-inter-sync.8*
%{_mandir}/man8/spacewalk-debug.8*
%{_mandir}/man8/satpasswd.8*
%{_mandir}/man8/satwho.8*
%{_mandir}/man8/spacewalk-fips-tool.8*
%{_mandir}/man8/spacewalk-remove-channel.8*
%{_mandir}/man8/spacewalk-repo-sync.8*
%{_mandir}/man8/spacewalk-data-fsck.8*
%{_mandir}/man8/spacewalk-update-signatures.8*
%{_mandir}/man8/update-packages.8*
%if 0%{?suse_version} >= 1210
%attr(644, root, root) %{_unitdir}/spacewalk-diskcheck.service
%attr(644, root, root) %{_unitdir}/spacewalk-diskcheck.timer
%endif

%files xml-export-libs
%defattr(-,root,root)
%doc LICENSE
%dir %{pythonrhnroot}/satellite_tools
%{pythonrhnroot}/satellite_tools/__init__.py*
%{pythonrhnroot}/satellite_tools/geniso.py*
# A bunch of modules shared with satellite-tools
%{pythonrhnroot}/satellite_tools/connection.py*
%{pythonrhnroot}/satellite_tools/diskImportLib.py*
%{pythonrhnroot}/satellite_tools/syncLib.py*
%{pythonrhnroot}/satellite_tools/xmlDiskSource.py*
%{pythonrhnroot}/satellite_tools/xmlSource.py*
%dir %{pythonrhnroot}/satellite_tools/exporter
%{pythonrhnroot}/satellite_tools/exporter/__init__.py*
%{pythonrhnroot}/satellite_tools/exporter/exportLib.py*
%{pythonrhnroot}/satellite_tools/exporter/xmlWriter.py*
%if 0%{?build_py3}
%dir %{pythonrhnroot}/satellite_tools/exporter/__pycache__/
%{pythonrhnroot}/satellite_tools/exporter/__pycache__/*
%endif

%files cdn
%defattr(-,root,root)
%attr(755,root,root) %{_bindir}/cdn-sync
%dir %{pythonrhnroot}/cdn_tools
%{pythonrhnroot}/cdn_tools/*.py*
%attr(755,root,%{apache_group}) %dir %{_var}/log/rhn/cdnsync
%config(noreplace) %{_sysconfdir}/logrotate.d/spacewalk-backend-cdn
%{_mandir}/man8/cdn-sync.8*
%if 0%{?suse_version}
%dir %{pythonrhnroot}/cdn_tools
%if 0%{?build_py3}
%dir %{pythonrhnroot}/cdn_tools/__pycache__/
%{pythonrhnroot}/cdn_tools/__pycache__/*
%endif
%endif

%changelog
* Thu Apr 23 2020 jgonzalez@suse.com
- version 4.0.31-1
- validate cached package entries on ISS slave (bsc#1159184)
- Do not break when syncing Oracle 7 yum channel (bsc#1158463)
- Always use the same RPM database when running "spacewalk-repo-sync"
  from the command line or via taskomatic (bsc#1163468)
* Fri Feb 28 2020 jgonzalez@suse.com
- version 4.0.30-1
- fix mgrcfg-client python3 breakage (bsc#1164309)
- update doc link to point to new documentation server
- Prevent timestamp format exception on mgr-inter-sync while processing comps (bsc#1157346)
- When downloading repo metadata, don't add "/" to the repo url if it already ends with one (bsc#1158899)
- Use HTTP proxy settings when fetching the mirrorlist on spacewalk-repo-sync (bsc#1159076)
- enhance suseProducts via ISS to fix SP migration on slave server (bsc#1159184)
- prevent a traceback when reposyncing openSUSE 15.1 (bsc#1158672)
- close config files after reading them (bsc#1158283)
- Associate VMs and systems with the same machine ID at bootstrap (bsc#1144176)
* Mon Nov 25 2019 jgonzalez@suse.com
- version 4.0.29-1
- fix specfile for systems that do not yet use systemd
- fix spacewalk-update-signatures for python3 (bsc#1156521)
- fix problems with Package Hub repos having multiple rpms with same NEVRA
  but different checksums (bsc#1146683)
* Tue Nov 12 2019 jgonzalez@suse.com
- version 4.0.28-1
- add systemd service macros for diskcheck.service
- port diskcheck utility to 4.0.3 branch (bsc#1156397)
- use active values for diskchecker mails
- do not require parameters to start on column 1
- Add Requires: systemd for completeness
- create /usr/lib/systemd/systemd during build
- BuildRequires: systemd for spacewalk-diskcheck
- add option spacecheck_shutdown; tidy up wording of notifications
- add disk space checker script
* Thu Oct 17 2019 jgonzalez@suse.com
- version 4.0.27-1
- fix re-registration with re-activation key (bsc#1154275)
* Thu Oct 17 2019 jgonzalez@suse.com
- version 4.0.26-1
- Change the default value of taskomatic maxmemory to 4GB
- Add basic support for importing modular repositories
- Import additional fields for Deb packages
- Add script to update additional fields in the DB for existing Deb packages
- use active values for diskchecker mails
- parse restart_suggested flag from patches and set it as keywords (bsc#1151467)
- Improve error message when deleting channel that's in a content lifecycle project (bsc#1145769)
- Prevent "reposync" crash when handling metadata on RPM repos (bsc#1138358)
- Do not show expected WARNING messages from "c_rehash"
- fix misspelling in spacewalk-repo-sync (bsc#1149633)
- remove credentials also from potential rhn.conf backup files in spacewalk-debug (bsc#1146419)
- Do not crash 'rhn-satellite-exporter' with ModuleNotFound error (bsc#1146869)
- spacewalk-remove-channel check that channel doesn't have cloned channels before deleting it (bsc#1138454)
- Fix broken spacewalk-data-fsck utility (bsc#1131556)
- Add '--latest' support for reposync on DEB based repositories
- Do not try to download RPMs from the unresolved mirrorlist URL
- Fix encoding issues with DB bytes values (bsc#1144300)
- Fix import of rhnAuthPAM to avoid issues when using rhnpush.
- Avoid traceback on mgr-inter-sync when there are problems
  with cache of packages (bsc#1143016)
* Tue Aug 27 2019 jgonzalez@suse.com
- version 4.0.25-1
- Don't skip Deb package tags on package import (bsc#1130040)
* Tue Aug 27 2019 jgonzalez@suse.com
- version 4.0.24-1
- For backend-libs subpackages, exclude files for the server
  (already part of spacewalk-backend) to avoid conflicts (bsc#1148125)
- prevent duplicate key violates on repo-sync with long changelog
  entries (bsc#1144889)
* Tue Jul 30 2019 jgonzalez@suse.com
- version 4.0.23-1
- do not overwrite comps and module data with older versions
- fix issue with "dists" keyword in url hostname
- import packages from all collections of a patch not just first one
- Ensure bytes type when using hashlib to avoid traceback
  on XMLRPC call to "registration.register_osad" (bsc#1138822)
* Thu Jun 20 2019 jgonzalez@suse.com
- version 4.0.22-1
- Do not duplicate "http://" protocol when using proxies with "deb"
  repositories (bsc#1138313)
* Thu Jun 20 2019 jgonzalez@suse.com
- version 4.0.21-1
- Fix reposync when dealing with RedHat CDN (bsc#1138358)
- Fix for CVE-2019-10136. An attacker with a valid, but expired,
  authenticated set of headers could move some digits around,
  artificially extending the session validity without modifying
  the checksum. (bsc#1136480)
* Thu Jun 13 2019 jgonzalez@suse.com
- version 4.0.20-1
- Prevent FileNotFoundError: repomd.xml.key traceback (bsc#1137940)
* Tue Jun 11 2019 jgonzalez@suse.com
- version 4.0.19-1
- Add journalctl output to spacewalk-debug tarballs
- Prevent unnecessary triggering of channel-repodata tasks when GPG
  signing is disabled (bsc#1137715)
* Thu May 30 2019 jgonzalez@suse.com
- version 4.0.18-1
- Fix spacewalk-repo-sync for Ubuntu repositories in mirror case (bsc#1136029)
- Add support for ULN repositories on new Zypper based reposync.
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.17-1
- use new names in code for client tool packages which were renamed (bsc#1134876)
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.16-1
- SPEC cleanup
- Fix password prompt within mgr-sign-metadata
- Fix TypeError for 'errata.getErrataInfo' XMLRPC handler (bsc#1132346)
- fix typo in syncing product extensions (bsc#1118492)
- Fix mgr-sign-metadata-ctl checking of exported keys.
* Thu Apr 25 2019 jgonzalez@suse.com
- version 4.0.15-1
- Use suseLib.get_proxy to get the HTTP proxy configuration
  properly on DEB repos (bsc#1133424)
* Mon Apr 22 2019 jgonzalez@suse.com
- version 4.0.14-1
- Add support for mirrorlist and metalink on Zypper reposync.
- Solve situations where synced packages have epoch 0 but reposync
  does not find them them on the database.
- Fix path to the RPM database used by Zypper at reposync.
- add makefile for python linter and unit/integration tests
* Mon Apr  8 2019 jgonzalez@suse.com
- version 4.0.13-1
- fix linking of packages in reposync (bsc#1131677)
* Fri Mar 29 2019 jgonzalez@suse.com
- version 4.0.12-1
- Include arch to distinct latest packages on reposync.
- Migrate missing spacewalk-cfg-get script to Python3
- Improve dependency solving algorithm for spacewalk-repo-sync.
* Mon Mar 25 2019 jgonzalez@suse.com
- version 4.0.11-1
- remove apache access_compat module and adapt config files
- Add support for getting latest versions from RPM packages
  when running "spacewalk-repo-sync" after migration to Zypper.
- Include packages dependencies on "spacewalk-repo-sync" when using filters
  for RPM packages.
- Allow package filtering (name matching) on spacewalk-repo-sync after
  migrating away from yum.
- Fix crash when importing new channel families on 'mgr-inter-sync' (bsc#1129300)
- Make Zypper to use the spacewalk GPG keyring in reposync (bsc#1128529)
- Fix: handle non-standard filenames for comps.xml (bsc#1120242)
- Make reposync use and append token correctly to the URL
- Avoid DB constraint violations caused by extended UTF8 characters on the RPM headers
- Prevent mgr-inter-sync crash because 'SuseProductRepository' not found (bsc#1129300)
- Fix invalid mode error when doing spacewalk-repo-sync on Ubuntu
  official repos.
* Tue Mar 12 2019 jgonzalez@suse.com
- version 4.0.10-1
- Make sure the package download url does not have '//' (bsc#1127488)
- Fix bootstrapping SLE15 traditional client (bsc#1128564)
* Mon Mar  4 2019 jgonzalez@suse.com
- version 4.0.9-1
- fix reading LOB objects with python3
* Sat Mar  2 2019 jgonzalez@suse.com
- version 4.0.8-1
- Fix "mgr-inter-sync" problems after Python 3 migration.
- mgr-sign-metadata can optionally clear-sign metadata files
- Added 'mgr-sign-metadata-ctl' for repository metadata signing
* Wed Feb 27 2019 jgonzalez@suse.com
- version 4.0.7-1
- Allow errata import from local repositories.
- Fix "rhnpush" after migration to Python 3.
- Fix package import issues when package encoding is ISO8859-1.
- Fix issues with HTTP proxy and reposync.
- Solve Python 3 problem and allow traditional registration.
* Fri Feb  8 2019 jgonzalez@suse.com
- version 4.0.6-1
- Add "python-urlgrabber" as a new dependency.
- Fix Python3 issues on satellite_tools scripts
* Thu Jan 31 2019 jgonzalez@suse.com
- version 4.0.5-1
- Use "Zypper" and "libsolv" in "spacewalk-repo-sync". Replace "yum".
- Require the correct dependency for python-rpm to allow the Proxy
  to work with Python3 only
- Make rhn-ssl-dbstore compatible with python3
* Wed Jan 16 2019 jgonzalez@suse.com
- version 4.0.4-1
- Take only text files from /srv/salt to make spacewalk-debug smaller (bsc#1103388)
- move channel update close to commit to avoid long lock (bsc#1121424)
- Adapt Inter Server Sync code to new SCC sync backend
* Mon Dec 17 2018 jgonzalez@suse.com
- version 4.0.3-1
- Fix issue raising exceptions 'with_traceback' on Python 2
- Hide Python traceback and show only error message (bsc#1110427)
- honor renamed postgresql10 log directory for supportconfig
* Fri Oct 26 2018 jgonzalez@suse.com
- version 4.0.2-1
- support mirroring of source packages
- Make spacewalk-backend code compatible with Python 3
- Channels to be actually un-subscribed from the assigned systems when being removed
  using spacewalk-remove-channel tool(bsc#1104120)
- Prepare spacewalk-backend packages to build on Python 3
- Replace PyPAM with python-python-pam
* Fri Aug 10 2018 jgonzalez@suse.com
- version 4.0.1-1
- Bump version to 4.0.0 (bsc#1104034)
- Fix copyright for the package specfile (bsc#1103696)
- fix directory permissions (bsc#1101152)
- Feature: implement optional signing repository metadata
- Fix truncated result message of server actions (bsc#1039043)
- Do not copy 'foreign_entitlement' from virtual host to the
  registered guest (bsc#1093381)
- Disable Oracle support for openSUSE (bsc#1095804)
* Tue Jun  5 2018 jgonzalez@suse.com
- version 2.8.57.5-1
- spacewalk-debug: add Postgres configuration files
- Initial branding change for Uyuni (bsc#1094497)
* Wed May 16 2018 jgonzalez@suse.com
- version 2.8.57.4-1
- Bugfix: do not fail boostrap if no ip6addr interface (bsc#1090395)
- allow again to use a higher version of spacewalk-backend-libs
  with spacewalk-backend (bsc#1092383)
* Mon May  7 2018 jgonzalez@suse.com
- version 2.8.57.3-1
- Sync with upstream (bsc#1083294)
* Mon Apr 23 2018 jgonzalez@suse.com
- version 2.8.57.2-1
- Fix encoding for RPM package group in reposync (bsc#1083001)
- Sync with upstream (bsc#1083294)
- 1567157 - remove 'www' part from cve.mitre.org domain name
- 1198723 - rhnRepository.py: add support for Debian / Ubuntu Release files
- 1549546 - Allow spacewalk-channel to add parent channel
* Wed Apr  4 2018 jgonzalez@suse.com
- version 2.8.56.3-1
- Temporary revert bsc#1083001
* Thu Mar 29 2018 jgonzalez@suse.com
- version 2.8.56.2-1
- SLE15 support: recommended/required flag for products and
  channels (bsc#1087373)
* Mon Mar 26 2018 jgonzalez@suse.com
- version 2.8.56.1-1
- Sync with upstream (bsc#1083294)
- Updating .po translations from Zanata
- Fixing incorrect syntax of format string
- Fixing newline error in translation
* Mon Mar  5 2018 jgonzalez@suse.com
- version 2.8.52.1-1
- 1550001 - KeyError: 'severity' caught when exporting channel with rhn-satellite-exporter
- 1534417 - sanitize pwds in backup files and http-proxy-pwds as well
- remove empty clean section from spec (bsc#1083294)
* Fri Feb 23 2018 jgonzalez@suse.com
- version 2.8.48.1-1
- 1540981 - Clarify error-reporting when checksum_cache is bad
- 1537098 - Teach packageImport to ignore flags RPM doesn't know
- add --no-packages option to spacewalk-repo-sync
- use --force-all-errata only to re-sync patches
  - -deep-verify still used for package checksum check and single
  errata import (bsc#1077244)
* Mon Feb  5 2018 jgonzalez@suse.com
- version 2.8.41.3-1
- use GTM for rpm build_time (bsc#1078056)
* Fri Feb  2 2018 jgonzalez@suse.com
- version 2.8.41.2-1
- fix spacewalk-data-fsck restore of broken package db entry (bsc#1071526)
- support multiple FQDNs per system (bsc#1063419)
* Wed Jan 17 2018 jgonzalez@suse.com
- version 2.8.37.1-1
- fix issues with syncing deb repos (bsc#1050433)
- honor MAX_LOG_AGE for (renamed) cobbler/tasks logs file
  in spacewalk-debug (bsc#1025201)
- add hostname to duplicate machine_id email (bsc#1055292)
- fix link to manual and the described procedure
- don't crash when token is set to 'fake' (bsc#1060022)
- when searching for not installed products exclude release packages
  which are provided by others (bsc#1067509)
- search for product packages when installed packages are available
  (bsc#1060182)
- rhnServerNetwork refactoring (bsc#1063419)
- Fix: restore hostname and ip*addr in templated documents (bsc#1075044)
- fix directory name in spacewalk-data-fsck
- search for product packages when installed packages are available
  (bsc#1060182)
- rhnServerNetwork refactoring (bsc#1063419)
* Fri Nov 10 2017 mc@suse.de
- version 2.8.27.1-1
- Change the virtualization backend not to duplicate data in case
  host and guests are in different organizations
- fix joining strings
- yum ContentSource() should set number of packages during raw listing.
- convert release to long while checking which is older or newer
- Do not import ignored errata
- process comps file before package import
- yum on RHEL6 has no idea about environments
- make rhn_rpm python3 compatible
- open checksummed files in binary mode
- mention package groups in help
- detect and parse package groups in filters
- add new spacewalk-repo-sync command line option to synopsis of man-page
- add new parameter '--show-packages' for spacewalk-repo-sync.
* Thu Oct 26 2017 mc@suse.de
- version 2.8.15.1-1
- build python3 subpackage for -libs package
- fix issues with syncing deb repos (bsc#1050433)
- honor MAX_LOG_AGE for (renamed) cobbler/tasks logs file
  in spacewalk-debug (bsc#1025201)
- add hostname to duplicate machine_id email (bsc#1055292)
- fix link to manual and the described procedure
- don't crash when token is set to 'fake' (bsc#1060022)
- when searching for not installed products exclude release packages
  which are provided by others (bsc#1067509)
* Thu Sep 14 2017 mc@suse.de
- version 2.7.73.9-1
- Fix SP migration for traditional clients which were registered
  by a currently disabled user (bsc#1057126)
* Wed Aug 30 2017 mc@suse.de
- version 2.7.73.8-1
- increase rpclib timeout to 10 minutes (bsc#1026930)
* Wed Aug  9 2017 fkobzik@suse.de
- version 2.7.73.7-1
- disable pylint check during build also for RHEL7
* Tue Aug  8 2017 fkobzik@suse.de
- version 2.7.73.6-1
- make master_label static to keep its value when retrying (bsc#1038321)
- adapt for the new gpgcheck flag for the channels
* Mon Jun 12 2017 mc@suse.de
- version 2.7.73.5-1
- Removing conflicting epoch fix (bsc#1042861)
- remove not implemented option --force-all-packages (bsc#1040194)
- fix parsing oscap results - not every Rule has an
  XCCDF ID Tag (bsc#1041992)
* Mon May 29 2017 mc@suse.de
- version 2.7.73.4-1
- move to different file to not conflict with web.default_mail_from
  in Java code
- don't trim channel content if there is major sync error in any
  repository
- disable pylint on Fedora 26 because it's python3
- rhn-charsets is meant to be run only under root user
- hashlib is included in python since RHEL6
- Unable to run cdn-sync if older channels do not exist anymore
* Tue May 23 2017 mc@suse.de
- version 2.7.73.3-1
- add missing bugnumber to changelog
* Tue May 23 2017 mc@suse.de
- version 2.7.73.2-1
- don't let disabled user log in
- updating help and man page
- satellite-sync (iss) - enhancements to channel selection
- make batch size configurable
- wildcard support for channel names
- optimize linking packages to channel
- disassociate packages later or keep them in channel if
  they are same but missing package path
- Rename incomplete_package_import to package_import_skip_changelog
- spacewalk-backend should require the exact version of spacewalk-backend-libs
  (bsc#1037635)
- try to finish work in threads when KeyboardInterrupt occurs during
  download
- fix errata lookup for NULL org
- optimize package importing during syncing a software channel
- allow sync of the same erratum to more orgs
* Thu May  4 2017 can.bulut.bayburt@suse.com
-  Non admin or disabled user cannot make changes to a system anymore
  using spacewalk-channel (CVE-2017-7470) (bsc#1026633)
* Wed May  3 2017 michele.bologna@suse.com
- version 2.7.73.1-1
- Repository sync can causes ORA-01878 on insertion of timestamp that
  doesn't exist in timezone - fix python 2.4 build
- do not store SSL certificates per repository on disk cache
- Prevent ORA-01878 on repository sync.
- default_mail_from key exists but may be empty
- (bsc#1024923) fixed a typo in SQL statement
* Mon Apr  3 2017 mc@suse.de
- version 2.7.65.1-1
- update man page
- adding Candlepin API to call manifest refresh
- call Candlepin API to download manifests and implement missing
  pieces of code
- adding handler for calling Candlepin API requests with export
  manifest support
* Fri Mar 31 2017 mc@suse.de
- version 2.7.63.1-1
- create scap files dir beforehand (bsc#1029755)
- do not fail with traceback when media.1 does not exist (bsc#1032256)
- adapt new proxy setting
- python3 compatibility changes
- filter channels to removed by patern with '*' - e.g. 'fedora19*'
  interrupt downloading
- if package was not downloaded and message-less Exception catched,
  don't print empty line and don't print to stream on default verbose setting
- show list of non-available channels at the beginning of syncing
- ignore channels which are not exist or not available
- show error message if we cannot download repomd.xml during counting
  packages
- fix http proxy configuration for yum_src
- fix package downloading for Kickstart addons. Add parsing repodata
  for addons repository and download all packages according to its location.
- fix reading repo certificates (bsc#1029022)
- fixing 'WARNING:  there is already a transaction in progress' in
  postgresql logs
- cleanup orphaned repositories not attached to any channel
- ContentSourceImport can't unlink last associated repository, do it
  differently
- break mappings dependency on spacewalk
- list custom CDN channels and sorting repositories
- make sure content is in null org, not in custom org
- filter channels with lost entitlement and include custom repos with
  null content source assigned
- Move aa-spacewalk-server.conf to backend from server
- do not package common/__init__ to prevent file conflicts with spacewalk-usix
- incomplete_package_import: do import rhnPackageFile as it breaks some package
  installations
* Tue Mar  7 2017 mc@suse.de
- version 2.7.50.1-1
- Don't skip 'rhnErrataPackage' cleanup during an errata update (bsc#1023233)
- set scap store dir mod to 775 and group owner to susemanager
- fix errata sync
- provide option for forcibly syncing all errata, similarly as in
  satsync
- do not import always all errata by default for performance reasons
- don't re-insert existing files again
- Updated links to github in spec files
- sync RPM packages for addons in Kickstart Tree
- Add support for running spacewalk-debug without creating reports.
  (bsc#1024714)
- install product packages during traditional registration
- Fix selection of primary interface
- trigger repodata generation after and only if channel packages are
  updated
- do not re-subscribe packages to channel if nothing was added
- Remove legacy audit logging Python code
- Add strict-httpd-workaround *FIRST* in httpd conf files
- Postgresql 9.6 support
- fixing 'ERROR: expected a readable buffer object' on Oracle
- catch exception InvalidArchError and send back an error message
- require spacewalk-usix indead of spacewalk-backend-usix
- support importing KS files with other checksum type than md5
- adding more details of current SSL certificates in DB
- support creating repository tree with only repos provided by single
  client certificate
- catch on higher level to not mark missing repositories as found
  repositories with no SSL certificates
- check SSL dates in reposync
* Tue Feb  7 2017 michele.bologna@suse.com
- version 2.7.28.1-1
- Align with upstream versioning
* Wed Jan 11 2017 michele.bologna@suse.com
- version 2.7.18.1-1
- Version 2.7.18-1
* Fri Dec 16 2016 michele.bologna@suse.com
- version 2.5.24.7-1
- Handle non-unique machine_id after migrate from 2.1 (bsc#1013002)
- Refer to scc.suse.com instead of bugzilla.novell.com in case of problem
  (bsc#967818)
- Fix: selection of primary interface bsc#1009677
- spacewalk-backend.spec: add link to SUSE name of program (bsc#1009435)
- Reposync - assign orphaned vendor packages to the default org (bsc#995764)
* Thu Oct  6 2016 mc@suse.de
- version 2.5.24.6-1
- Fix for non-integer IDs for bugzilla bug
- silently ignore non-existing errata severity label on errata import,
  remove non-used exception (bsc#986447, bsc#996609)
- make suseLib usable on a proxy
* Mon Jul 18 2016 jrenner@suse.com
- version 2.5.24.5-1
- copy the subscription-matcher directory instead of the content
- machine_info capability and check for client tool compatibility with Suma 2.1
- modify test setup for oracle DB
* Tue Jun 14 2016 kwalter@suse.com
- add machine info capability
* Tue May 24 2016 kwalter@suse.com
- version 2.5.24.4-1
- spacewalk-repo-sync - Improved date handling (bsc#975161)
- better error message for system that is already registered as minion
- Only trigger virtualization notification on server save when the
  virtualization data is not falsy (bsc#975120)
- fix GPG bad signature detection and improve error messages (bsc#979313)
- send and save machine_id on traditional registration
- vendor channels may have no repo assigned (bsc#977781)
- do not crash now that multiple urls are passed (bnc#970951)
* Wed Apr  6 2016 mc@suse.de
- version 2.5.24.3-1
- Include the Matcher data directory in supportconfig
- qemu-kvm guests created on my Fedora 22 have different signature
- fix SLE12 patch style detection in case of cloned patches (bsc#972972)
- Grab the entire pillar structure at once
- trigger regeneration of metadata on product or keyword changes (bsc#972096)
- Find all user configured places of the custom pillars and get an info about
  them
- Rename static Salt states directory
- Gather also static pillars
- Add missing title about custom Salt states
- Check if directory exists at all prior checking its content
- Copy all Salt state files and generated pillars
- Copy all Salt Master configuration
* Mon Mar 21 2016 mc@suse.de
- version 2.5.24.2-1
- Fix rhnreg_ks doesn't work with activation key
- update checksumtype after setting the SSL values (bsc#970824)
* Wed Mar  9 2016 mc@suse.de
- version 2.5.24.1-1
- include salt master config files into spacewalk-debug
- we need to import either cx_Oracle or psycopg2
- better never import foreign private channel families, custom
  channels will be synced into your org anyway
- org_id of channel family is probably never filled, just not make
  private channel families public
- all strings should be truncated, not only unicode instances
* Wed Mar  2 2016 mc@suse.de
- version 2.5.22.1-1
- make sure truncated value does not contain incomplete characters
- allow sat-sync-error-email to be configurable
- Remove custom latest RPM handling in spacewalk-repo-sync and use
  the same logic as reposync from yum-utils instead.
- honor no_proxy variable in InterServerSync (bsc#965651)
* Wed Feb 10 2016 mc@suse.de
- version 2.5.18.1-1
- provide empty no_proxy variable for reference in rhn.conf
- do not import errata to all synced channels because some may not
  have all packages synced
- advise users to purge satsync cache on IntegrityError
- making sure packages without errata are included
- fixing invalid query
* Tue Jan 26 2016 mc@suse.de
- version 2.5.13.1-1
- update guest also on re-registration
- allow to change uuid of already registered guests
- there can be guests without hypervisor registered
- fixing exception when reactivating system without base channel and without
  any available
- use 2048MB as default for taskomatic max java memory
- add comment about taskomatic jvm max memory to rhn.conf (bsc#957653)
- Added filename in the error message of satellite-sync, in case file
  has wrong size
- Added processing of ValueError exception, during spacewalk-data-
  fsck
- local variable 'primif' referenced before assignment
* Sat Jan 16 2016 mc@suse.de
- version 2.5.10.1-1
- cleaning few old translations
* Thu Jan 14 2016 mc@suse.de
- version 2.5.9.1-1
- removing old duplicate template file
- allow client responses to be in Unicode
- cut string after full characters (bsc#960801)
* Tue Jan  5 2016 mc@suse.de
- version 2.5.8.2-1
- update CPU only if it has changed
- set "last_boot" and "os" for the host
- read SystemInfomation, create a foreign mainframe system
  and link to virtual instance
- add "mainframe_sysinfo" capability
* Wed Dec 16 2015 mc@suse.de
- version 2.5.8.1-1
- making synced channels in null org visible to all orgs
- during installation insert default SSL crypto key with null org
- fix typos
* Thu Dec 10 2015 mc@suse.de
- version 2.5.4.2-1
- avoid referencing unassigned variable (bsc#956981)
* Mon Nov 30 2015 mc@suse.de
- version 2.5.4.1-1
- Fix lookup virtual instance by uuid in virtualization backend in case so that
  it ignores the host id when uuid is not null. Removed invalid comment.
- Change the virtualization backend not to duplicate data in case host and
  guests are in different organizations
- fix patch syning if no issued date is given. Use now as date (bsc#953584)
- fix SUSE patch style detection for RES4 (bsc#953825)
- move support report creation to spacewalk-debug
- don't print python object details in reposync.py
- spacewalk-repo-sync: support multiple '-c channel' as in satellite-sync
* Thu Oct 22 2015 mc@suse.de
- version 2.5.1.2-1
- use sle_version macro while checking for SLE only
* Wed Oct  7 2015 mc@suse.de
- version 2.5.1.1-1
- drop monitoring
- replace upstream subscription counting with new subscription
  matching (FATE#311619)
- integrate SaltStack for configuration management (FATE#312447)
* Sun Sep 27 2015 mc@suse.de
- version 2.1.55.21-1
- read repository checksum type after setting the certificate
  for a repository
* Wed Sep 23 2015 mc@suse.de
- version 2.1.55.20-1
- define db_password to be read as a string (bsc#946381)
* Wed Jul 29 2015 mc@suse.de
- version 2.1.55.19-1
- Enhance date only in patches to full ISO datetime (bsc#937029)
- Fix UnboundLocalError on rhnFault in dist upgrade (bsc#936182)
- detect new and old SUSE patch style (bsc#936869)
* Tue Jun 23 2015 jrenner@suse.de
- version 2.1.55.18-1
- Require pyliblzma to enable sync of EPEL repos (bsc#934417)
* Mon Jun 22 2015 jrenner@suse.de
- version 2.1.55.17-1
- detect SUSE Manager Tools channel as well (bsc#935433)
- import RPMs which vendor is an empty string (bsc#934124)
- set primary interface during registration (bnc#929058)
- do not reset primary network interface at hardware refresh (bnc#895071)
* Tue Mar 31 2015 mc@suse.de
- version 2.1.55.16-1
- Copyright texts updated to SUSE LLC
- package inventory and channel report into spacewalk-debug
- Adding on the spacewalk-data-fsck man page the option --remove-mismatch
- add funcionality on spacewalk-data-fsck to remove the RPM which does not
  match checksum
- Fix the primary key definition for rhnPackageFile
- don't crash re-registrations if the original owner has been deleted
- sw-repo-sync fix to sync kickstart.
- init the second DB connection only when needed (inspired by bsc#915581)
- check for reboot type only (inspired by bsc#915581)
* Tue Feb  3 2015 mc@suse.de
- version 2.1.55.15-1
- convert mtime to localtime to prevent invalid times because of DST
  (bsc#914437)
- Do not exit with error if a vendor channel has no URL associated
  (bsc#914260)
- Getting rid of Tabs and trailing spaces
- copy all SUSE Manager logfiles into spacewalk-debug
- Update spacewalk-debug man page
- Exclude old backup-logs from spacewalk-debug to reduce size
- fix ISS export with unset patch severity
- ISS export/import informations about cloned channels (FATE#317789)
- convert empty string to null for DMI values (bsc#911272)
* Thu Dec 18 2014 mc@suse.de
- version 2.1.55.14-1
- fix encoding of submit message
- create (and label) /var/cache/rhn/satsync
- fixed double-counting of systems subscribed to more than one
  channel
* Thu Dec  4 2014 mc@suse.de
- version 2.1.55.13-1
- insert update tag at the correct place for SLE12 (bsc#907677)
- different registration paths should lock tables in the same order
  This could potentially cause deadlocks
- spacewalk-data-fsck: use config file variable instead of hardcoded path part
- drop unused column product_list in suseProducts table
- sanitize db_* config values
* Mon Nov 24 2014 mc@suse.de
- trigger generation of metadata if the repo contains no packages
  (bsc#870159)
* Fri Nov  7 2014 mc@suse.de
- version 2.1.55.12-1
- With NCC Backend still use the old style ISS method
- Make spacewalk-debug scc migration compatible
* Sat Nov  1 2014 mc@suse.de
- version 2.1.55.11-1
- ISS: Ignore errors if deprecated files do not exist on export
- ISS: export/import Subscriptions and entitlements
- ISS: remove old import code for NCC products and subscriptions
- ISS: export/import suseProductChannels and suseUpgradePaths via ISS
- ISS: export/import SUSE Products via ISS
- Fix cleanup when DB init goes wrong
- sanitize db_name config value
- fixed variable name
* Tue Oct 14 2014 mc@suse.de
- version 2.1.55.10-1
- require python-enum34
- update channel checksum type for vendor channels
- read mirror credenatials from DB depending on the cc_backend.
- move current_backend() from susemanager to backend and rename it to
  current_cc_backend
- Speed up satellite-sync by avoiding commonly-called dblink_exec
- backend should correctly checksum config files with macros in them
- Add /usr/share/rhn/config-defaults in spacewalk-debug
- fix spacewalk-debug to be fully postgreSQL aware.
- correct UTF8 config files from being marked as binary
- increase size of update_tag column in rhnChannel table
* Fri Sep 12 2014 mc@suse.de
- version 2.1.55.9-1
- preserve the query params in the url
- allow missing packages in patches if they are not part of this repo
- handle SLE12 update tag correctly in reposync
- fix traceback when pushing rpms with archive size > 4GB
- queue server for errata cache update when package list changes
- recognize oVirt node as virtual system
- adding handling for new rpm header information
* Wed Sep  3 2014 ro@suse.de
- sanitize release line in specfile
* Tue Jun 17 2014 jrenner@suse.de
- version 2.1.55.8-1
- Additional spacewalk backend methods and capability needed
- Spacewalk changes needed to support collisionless proxy lookaside
* Tue May 27 2014 mc@suse.de
- version 2.1.55.7-1
- Fix crash when EULA comes with broken encoding and unexpected
  symbols from the susedata.xml file
* Thu May 22 2014 mc@suse.de
- version 2.1.55.6-1
- spacewalk-update-signatures: fix logging, find more wrong keyids
    and remove existing associations before updating (bnc#874634)
- fixed 'empty separator' error
- Branding fixes
- fix syntax error in SQL statement
* Fri May 16 2014 mc@suse.de
- version 2.1.55.5-1
- ISS: fix EULA import on Oracle db
- add suseEula to RPM package
- package and install suseEula
- ISS: sync SUSE's package EULAs
- Parse and import packages' EULAs
* Wed May  7 2014 mc@suse.de
- version 2.1.55.4-1
- Revert "Adding option [-l|--list] to spacewalk-repo-sync"
* Tue May  6 2014 mc@suse.de
- version 2.1.55.3-1
- remove ; in SQL statement to fix error with oracle DB
- Raise error if channel cannot be subscribed (bnc#875958)
- Format oldRoute to match newRoute, so that rhnServerPath isn't
  updated every time
- Adding option [-l|--list] to reposync
- Add --justks to sw-remove-channel
- sw-remove-channel --justdb has no impact on ks trees.
- rename channel-with-childs to channel-with-children
- Add option to spacewalk-remove-channel parent
- Added spacewalk-data-fsck man page(8)
- uniquify repo-sync packages in case of bad metadata
- allow MD5 config file checksums in fips mode
- commit after adding a job to taskomatic queue
- generate empty metadata for repos without primary
- proper failure handle (bnc#822644)
* Thu Apr 10 2014 mc@suse.de
- version 2.1.55.2-1
* Thu Apr 10 2014 mc@suse.de
- fix release in specfile for SLE12 (bnc#872970)
* Thu Mar 27 2014 fcastelli@suse.com
- version 2.1.55.1-1
- Package lock - python code: handle multiple lock events
- Catch more error message from gpg
- Reposync: remove interrupted downloads [bnc#866490]
- Not all machines provide manufacturer, was not None safe
- Spacewalk-debug: dereference links [bnc#865934]
- Specify package only with version
* Thu Feb 27 2014 fcastelli@suse.com
- version 2.1.54.1-1
- workaround for rpm-python bug
- update openstack guest requirements
* Fri Feb 21 2014 fcastelli@suse.com
- version 2.1.52.1-1
- Detect OpenStack guests as virtual so they can consume flex guest
- Rename variable so it doesn't colide with reserved word
* Thu Feb 13 2014 mc@suse.de
- version 2.1.49.2-1
- query should not end with semicolon in oracle
- add /usr/share/rhn to filelist
- no pre-requires of spacewalk-config on SLE12
- make unittests work on python 2.7 and higher without
  extra package installed
- no pylint on SLE12
* Fri Feb  7 2014 mc@suse.de
- version 2.1.49.1-1
- add functions to query ISS Master server from DB
- apply exclude filters to dependencies in repo-sync
- don't remove files referenced from other distributions/trees
- propagate --skip-kickstart-trees to delete_channels()
- remove clean-reposync-logs cronjob
- fixed man page for spacewalk-remove-channel
- added option to skip kickstart trees removal
- sw-remove-channel does not rm ks trees.
- Inter server sync: export also errata's severity
- Fixing InvalidPackageError when importing from channel dump
- commit after updating server's package profile
- Add extra log folder /var/log/rhn/tasko/sat/ in spacewalk-debug.
  [bnc#854090]
- allow CVE-IDs with more then 13 chars
  new syntax since 2014
- fixing sat-sync daylight-savings-related 'NoneType is
  unsubscriptable' error
* Mon Jan 13 2014 mc@suse.de
- version 2.1.39.1-1
- set reboot action status to sucess after the reboot (FATE#312591)
- added setLocked actions (FATE#312359)
* Wed Dec 18 2013 mc@suse.de
- version 2.1.38.2-1
- allow 1 character system profile names
* Mon Dec  9 2013 mc@suse.de
- version 2.1.38.1-1
- better detection for SUSE KVM and Cloud systems
- support bootstrap entitlement for bare-metal registration
  (FATE#312329)
- use new ISS slave detection
* Thu Nov 28 2013 mc@suse.de
- version 1.7.38.30-1
- replace encode/decode with to_string/to_unicode
- make sure we put strings to fd.write()
- replace application code with database lookup to prevent conflicting
  inserts
- python server: better logging of exceptions
- log errors on bad request (bnc#849856)
- fixed table alias
- updated spacewalk-repo-sync's man page (bnc#846351)
- add support for enhances rpm weak dependencies (backend) (bnc#846436)
- python pgsql driver: handled ProgrammingError exceptions
- Fix typos in entitlement report (bnc#840751)
* Fri Sep 27 2013 mc@suse.de
- version 1.7.38.29-1
- with deep-verify import patches step by step
- check if mountpoint exists and send error mail (bnc#839111)
- bool(0) == False, but is a valid file mode
* Tue Aug 27 2013 mc@suse.de
- version 1.7.38.28-1
- Ensure the file object is closed only when no IOError took place
  (bnc#837035)
* Wed Aug 21 2013 mc@suse.de
- version 1.7.38.27-1
- add option to disable Expect header for post request (bnc#834200)
- re-import all patches with param deep-verify (bnc#833643)
- rewrite package org to match where they got imported (bnc#834780)
- Fix field length of erratum-advisory-name to match real DB field length
- forward register and de-register requests to parent
- debranding satellite-sync
- provide dummy repoindex handler for auth test in ISS case
- use needed mgr_ncc_sync_lib calles in satellite-sync
- copy SUSE product and subscription information into the disk dump
- add handler for ncc sync data used by iss (bnc#832776)
- package mgr-inter-sync and mgr-exporter commands (FATE#312371)
- import/export Support Information
- sync suseProductFiles with inter-server-sync
- dump and read rhn-channel-update-tag
- Add curl debugging to send and accessible (bnc#834200)
- filter out bad package/architecture combinations
- add debug code to import_susedata
- handle unicode tracebacks
- handle compressed products file
- Fix pylint errors - bnc#829073
- Fix code to work with python 2.4 - bnc#829073
- Make reposync work with local repositories - bnc#829073
* Wed Jun 12 2013 mc@suse.de
- version 1.7.38.26-1
- fix reactivation of systems (bnc#823241)
- remove incorrect path from db
- Adding file path restoration functionality to spacewalk-data-fsck
- update copyright column length
- don't truncate channel name to 64 chars
- make API compatible with old RHEL5 clients
- No line break at the end of the package summary (bnc#821968)
- don't truncate filepath when exporting
- fix registration issues on PG
- update expired gpg keys in the keyring
- set copy_local urlgrabber option to copy also file URLs (bnc#819781)
- implement no_proxy usage (FATE#315039)
- use timeout config option also in suseLib send function (bnc#815460)
* Fri May 17 2013 mc@suse.de
- version 1.7.38.25-1
- make satellite-sync work with new rhnlib (bnc#815460)
- search for CVE numbers also in the description
- require rhnlib with timeout option
- make rpclib connection timeout configurable (bnc#815460)
- return 404 Not Found on requests of content or installation.xml (bnc#815441)
- fix encoding in products summary and description
* Fri May 17 2013 mc@suse.de
- fix authentication checking in inter server sync
  CVE-2013-2056 (bnc#819365)
* Thu Apr  4 2013 mc@suse.de
- version 1.7.38.24-1
- Write better error message if the GPG key is not imported
  (bnc#812599)
- correct size for old rpms > 2 GiB
- do not read rpm into memory before transferring to client
  (bnc#801151)
- do not log passwords in URL
- If the database host is localhost, use Unix sockets in backend.
- SSH Server Push (backend) (FATE#312909)
- support V4 RSA/SHA1 signature
- Use FQDN in reposync error emails
- fix unicode encoding (bnc#803866)
- do not change the channels on future actions request
* Fri Feb  8 2013 mc@suse.de
- version 1.7.38.23-1
- send patch notifications only for new patches (FATE#314765)
- log with debug level, if wanted
- collect download errors and send error mail (bnc#801189)
- compare patch version as integers
- do not send null values for new products via XMLRPC (bnc#798131)
- change_base_channel should honor suse_products info if available
* Tue Dec 18 2012 mc@suse.de
- version 1.7.38.22-1
- fix formatstring error with proxy user and password
* Tue Nov 27 2012 mc@suse.de
- version 1.7.38.21-1
- remove product reference while deleting channel (bnc#790987)
* Thu Nov 22 2012 jrenner@suse.de
- version 1.7.38.20-1
- fix is_sha256_capable() function (bnc#790717)
- use SUSE specific proxy settings in reposync (bnc#779992)
- read proxy from rhn.conf before other places
- fix wrong variable binding (bnc#790143)
- rollback any unfinished transaction
- for the installed_size, ignore situation when it was not populated
  in the database.
- don't fail when from attribute is missing
- make sure proxy is enabled in sysconfig before reading it
- Add support for multiple mirror credentials
- SP migration backend (FATE#312431, FATE#312312)
- use smdba space-overview for report if exists
- do not return not existing patchnames (bnc#786105)
- add xmlrpc function update_status and server capability
* Fri Oct  5 2012 mc@suse.de
- version 1.7.38.19-1
* Thu Oct  4 2012 mc@suse.de
- version 1.7.38.18-1
- support upgrade_version without channel switching
* Fri Sep 28 2012 mc@suse.de
- version 1.7.38.17-1
- load suse_products in the server object if not available
- reposync: do not use a proxy to access localhost
- Adding IPv6 ip-address detection to proxy auth fix (bnc#783667)
- separate proxy auth error hostname into separate header
- multi-tiered proxies don't update auth tokens correctly
  (bnc#783667)
* Tue Aug  7 2012 mc@suse.de
- version 1.7.38.16-1
- fix SQL syntax for postgres
* Thu Aug  2 2012 mc@suse.de
- version 1.7.38.15-1
- Truncating date string and therefore preventing ORA-01830
- skip ignored errata also in the second step (bnc#773108)
- fix detection of old suse style patches (bnc#773108)
- Fixing placeholder syntax in sql statement
* Thu Jul 19 2012 ug@suse.de
- version 1.7.38.14-1
- yet another branding fix
* Mon Jul 16 2012 ug@suse.de
- version 1.7.38.13-1
- postgresql don't know about decode
- fixed ERROR: subquery in FROM must have an alias
- fixed AttributeError: 'buffer' object has no attribute 'write'
- Correct SQL query for installing and removing solaris patches
- Correct query for PGSQL, addressing: SQL syntax error
- man page fix and root-level user warning for rhn-satellite-exporter
* Mon Jun 25 2012 mc@suse.de
- version 1.7.38.12-1
- handle locally exception in entitle_server()
- made error message more detailed
* Thu Jun 21 2012 jrenner@suse.de
- version 1.7.38.11-1
- removed functions which were orphaned by client v1 API removal
- fix call of save_suse_products()
- do not entitle virt guests twice during registration
- fix parsing susedata (bnc#765667)
- removed support for Red Hat Linux 6.2 and 7.[0123]
- print reasonable error message when something wrong with repo
* Wed Jun  6 2012 ug@suse.de
- added a workaround for bnc#761350
  registering of a VM does not work
* Fri Jun  1 2012 mc@suse.de
- fix ISE during registration because of duplicate ids
  (bnc#765123)
* Thu May 31 2012 mc@suse.de
- version 1.7.38.10-1
- decode unicode string on IDN machines
- mock import_susedata
- allow retrieving susedata.xml.gz
- implement get_susedata()
- implement import_susedata()
* Mon May 14 2012 mc@suse.de
- version 1.7.38.9-1
- fix registration of virt. machines (bnc#761350)
* Mon May 14 2012 mc@suse.de
- version 1.7.38.8-1
- better check for empty version, release and arch
- with postgres empty varchar has to be null
- fix CVE test in testsuite
- improve patch handling for broken updateinfo files
* Wed May  9 2012 mc@suse.de
- version 1.7.38.7-1
- define python macros
- No need to be autonomous when inserting to rhnArchType,
  only satellite-sync does it.
* Tue May  8 2012 ug@suse.de
- integrated upstream feedback for studio integration (bnc#764532)
* Wed May  2 2012 mc@suse.de
- version 1.7.38.6-1
- no fileprovide of gettext in SUSE
- Assign a dummy profile when none is selected.
- xccdf_eval should not send null value
* Fri Apr 27 2012 mc@suse.de
- version 1.7.38.5-1
- update monitoring probes in small batches to reduce the chance of a
  deadlock
- raise SQLSchemaError alike oracle driver does
- fix sql query with --use-sync-date and --start-date of
  rhn-satellite-exporter
* Fri Apr 20 2012 mc@suse.de
- version 1.7.38.4-1
- Fix inserting installed products
- set a bug title if we do not get one
- The mod_wsgi insists on having something after the numeric value on the
  Status line.
- Workaround httplib in 2.4 which did not have the responses dictionary.
- write nicer error message in case you are missing rpm files
- update man-pages
- copy postgres initlog in SUSE
- adding PostgreSQL configuration and log files to the debug.
- updating rhn-charsets man page -- update list of value names, no
  command line options.
- make rhn-charsets working on PostgreSQL as well; the output format
  changed even for Oracle.
* Fri Apr 13 2012 mc@suse.de
- version 1.7.38.3-1
- Update config default to preserve base channel on reactivation
- rhn-schema-stats: support for PostgreSQL
- rhn-db-stats: support for PostgreSQL
- check channel permissions when unsubscribing a channel
- fix empty references in updateinfo
- remove source packages from compatible arch. We do not mirror them.
* Fri Apr 13 2012 ug@suse.de
- fixed packaging of spacewalk-backend-xmlrpc
- fixed python bug in SUSE Studio image deployment
* Fri Mar 30 2012 mc@suse.de
- version 1.7.38.2-1
- Truncate data which are longer than db allows
- Store also @idref of xccdf:rule-result element
- We want to store all idents per rule-result
- return products.xml metadata on request
- fixing sql queries with alias
- need to use timestamp datatype to preserve the precision.
- cast to string to force lookup_evr prototype.
- spacewalk-repo-sync documentation fix : add include/exclude options to
  manpage
- add default value for taskomatic.channel_repodata_workers
- created module for usefull cli functions
* Sat Mar 24 2012 mc@suse.de
- parameters should not be None
* Thu Mar 22 2012 mc@suse.de
- rotate logfiles with user www (bnc#681984) CVE-2011-1550
* Thu Mar 22 2012 mc@suse.de
- fix arbitrary package upload (bnc#751837)
  CVE-2012-1145
* Wed Mar 21 2012 mc@suse.de
- version 1.7.38.1-1
- Bumping package version
* Fri Mar 16 2012 ug@suse.de
- replace passwords in debug files (bnc#752467)
* Thu Mar 15 2012 jrenner@suse.de
- Add support for studio image deployments
* Mon Mar  5 2012 mc@suse.de
- add suseLib.accessible() doing a HEAD request to test
  if a URL is accessible
* Tue Jan 31 2012 mantel@suse.de
- some more renames Novell --> SUSE
* Thu Jan 19 2012 jrenner@suse.de
- Setting up seclist in registration.py (bnc#782819, brc#749890)
- CVE-2012-0059
* Thu Jan  5 2012 mc@suse.de
- spacewalk-debug should package NCC data dump into the tar ball
* Thu Dec 22 2011 mantel@suse.de
- do not change server.pot
* Thu Dec 22 2011 mantel@suse.de
- rename Novell to SUSE (#708333)
* Thu Dec 22 2011 mc@suse.de
- remove all unsupported translations
* Mon Dec 19 2011 mc@suse.de
- parse products.xml during reposync and store values in the
  Database (bnc#644678)
* Mon Dec 12 2011 iartarisi@suse.cz
- Add new --deep-copy option to spacewalk-repo-sync to allow skipping
  the re-calculation of package checksums
* Tue Nov  8 2011 jrenner@suse.de
- Implement audit logging for the backend API (fate#312607)
* Wed Oct 26 2011 mc@suse.de
- add support for V4 DSA and RSA rpm signatures to display correct
  content provider (bnc#726577)
- enhance spacewalk-update-signatures to clean wrong keyids
  before update starts
* Thu Oct 13 2011 iartarisi@suse.cz
- fix reposync failure when trying to associate package which couldn't
  be downloaded (bnc#722917)
* Tue Oct 11 2011 mc@suse.de
- fix spacewalk-remove-channel to work on SUSE Manager (bnc#670206)
* Tue Oct 11 2011 mc@suse.de
- adapt spacewalk-debug for SUSE Manager
* Mon Oct 10 2011 mc@suse.de
- fix typo in reposync cleanup script (bnc#712860)
* Fri Oct  7 2011 iartarisi@suse.cz
- fix bug when parsing a patches.xml file with an extra <category> tag
* Wed Oct  5 2011 mc@suse.de
- drop incompatible packages of a patch
* Fri Sep 30 2011 mc@suse.de
- remove default currency from backend part of rhn.conf
* Thu Sep 29 2011 mc@suse.de
- set patch severity to Low if none is specified to get all
  security patches listed in the currency report
* Mon Sep 26 2011 iartarisi@suse.cz
- fix e['channels'].append AttributeError in case existing_errata is None
- fix failing unittest
* Mon Sep 26 2011 mc@suse.de
- fix loosing patches if a repository is synced into
  different channels (bnc#720312)
* Fri Sep 23 2011 mc@suse.de
- add unittests to check again
* Fri Sep 23 2011 mc@suse.de
- change BuildRoot to SUSE default required for BuildService
- recompile python after unittests to remove buildroot path
  in binaries
* Tue Sep 20 2011 iartarisi@suse.cz
- use pylint instead of python-pylint for checks
* Mon Sep 12 2011 iartarisi@suse.cz
- remove extra toy targets that we don't use from Makefile.defs, which
  were mangling the PYTHONPATH
* Mon Sep 12 2011 iartarisi@suse.cz
- run unittests and pylint from Makefile.backend at build time
* Fri Sep  9 2011 iartarisi@suse.cz
- fixed E:442:XML_Dumper._validate_channels: Too many arguments for
  format string
* Wed Sep  7 2011 mc@suse.de
- add cronjob to cleanup reposync log directory (bnc#712860)
* Wed Sep  7 2011 mc@suse.de
- refactor reposync
* Mon Sep  5 2011 iartarisi@suse.cz
- fix another typo in the specfile
* Mon Sep  5 2011 iartarisi@suse.cz
- fix typo in specfile
* Mon Sep  5 2011 iartarisi@suse.cz
- only run unittests during package build where we have the right
  BuildRequires
* Mon Sep  5 2011 iartarisi@suse.cz
- added suseLib.py - library that deals with NCC/proxy configs/products
  etc.
- make unittests run during package build
* Mon Aug 22 2011 iartarisi@suse.cz
- fixed TypeError in find_bugs method caused by empty patch descriptions
* Thu Aug 18 2011 iartarisi@suse.cz
- fixed an import error in diskImportLib.py
* Fri Aug 12 2011 iartarisi@suse.cz
- remove 'channel' from server.handlers.app as the sources have already
  been deleted (bnc#711967)
* Fri Aug 12 2011 kkaempf@novell.com
- Remove 'comps' from Makefile (bnc#711938)
* Fri Aug 12 2011 kkaempf@novell.com
- fix fetchTraceback and rhnFault import (bnc#711934)
* Thu Aug 11 2011 iartarisi@suse.cz
- fix more imports after the move from spacewalk.common
* Thu Aug 11 2011 iartarisi@suse.cz
- fix imports on UserDictCase to point to rhn.UserDictCase (bnc#711518)
* Wed Aug 10 2011 iartarisi@suse.cz
- removed implicit imports to spacewalk.common (fixes bnc#711214,
  bnc#711211, bnc#711434)
* Tue Aug  9 2011 iartarisi@suse.cz
- fixed missing import of 're' module (bnc#711188)
* Wed Aug  3 2011 iartarisi@suse.cz
- reposync: fix ambiguous message when skipping a patch which references
  a package that's not in the database (bnc#702932)
* Wed Jul  6 2011 mc@suse.de
- add server capability xmlrpc.errata.patch_names'
* Wed Jul  6 2011 mc@suse.de
- fix requires for Code10
* Wed Jun 29 2011 iartarisi@suse.cz
- added errata.getErrataNamesById function to the XMLRPC API
* Mon Jun  6 2011 mc@suse.de
- set RPM vendor to "Not defined" if the RPM say "(none)"
  (FATE#312378, bnc#693291)
* Tue May 24 2011 mc@suse.de
- some wierd packages have files in iso8859-1 not utf-8
- fix encoding of summary and description of a package if it is
  wrong
* Mon May 23 2011 mc@suse.de
- Improve error message when gpg key is wrong or missing
  (bnc#693574)
- do not trigger a resync if file is missing. This can cause
  an endless loop (bnc#695392)
- do not send tracebacks as email if reposync failed. Send only
  the error message. (bnc#691579)
* Mon May  9 2011 mc@suse.de
- fix errata export/import for sync
- handle sync with older spacewalk server which do not support
  weak dependencies
* Wed Apr 20 2011 iartarisi@suse.cz
- reposync - parse and insert zypper code10 patches into the database
* Thu Apr 14 2011 jrenner@suse.de
- Remove the channel APP handler (bnc#685078)
  (CVE-2009-0788, CVE-2010-1171)
* Fri Apr  1 2011 mc@suse.de
- fix adding patches to a channel. Treat no epoch as the same as
  epoch is 0 (bnc#682846)
* Thu Mar 31 2011 mc@suse.de
- fix a syntax error with old python versions
* Tue Mar 22 2011 iartarisi@suse.cz
- fixed bnc#673022 mirror timeout errors shouldn't cause tracebacks
* Thu Mar 17 2011 mc@suse.de
- check that path is not None
* Wed Mar 16 2011 iartarisi@suse.cz
- fixed bnc#679866 (downloading subscriptions fails when using integer
  credentials)
* Tue Mar  8 2011 iartarisi@suse.cz
- fixed bnc#644072 (password guessing vulnerability) with two commits
  from upstream
* Wed Feb 23 2011 ug@suse.de
- fixed virtual SUSE KVM machines in the webui (bnc#674344)
* Fri Feb 18 2011 mc@suse.de
- fix extract keyid from RPM header
* Thu Feb 17 2011 mc@suse.de
- do not remove not existing files
* Thu Feb 17 2011 mantel@suse.de
- fix debranding issues (bnc#672637)
* Tue Feb 15 2011 ug@suse.de
- typo fixed (indentation error bnc#671799)
* Mon Feb 14 2011 mc@suse.de
- expect not signed metadata with spacewalk-repo-sync if
  url is given on the commandline
* Sat Feb 12 2011 mc@suse.de
- send Mail if repo-sync failed
* Fri Feb 11 2011 jkupec@suse.cz
- correct strings in rhnException.py
* Fri Feb 11 2011 mc@suse.de
- catch exception primary not available and print nice message
  (bnc#671225)
* Thu Feb 10 2011 mc@suse.de
- remove org change again; fixed at another place
* Wed Feb  9 2011 jkupec@suse.cz
- removed unsupported satellite-sync from the
  spacewalk-backend-tools package (bnc #669610)
* Wed Feb  9 2011 mc@suse.de
- fix typo in sql statement
* Wed Feb  9 2011 mantel@suse.de
- some more renames of RHN to NCC (BNC#668824)
* Wed Feb  9 2011 mantel@suse.de
- change name of default organization (BNC#663983)
* Tue Feb  8 2011 mc@suse.de
- change mountpoint and prepended_dir (bnc#669558)
* Tue Feb  1 2011 mc@suse.de
- fix building on RH
* Mon Jan 31 2011 mc@suse.de
- call yum update_md with the option to get all updateinfos
  and not only the newest (bnc#668333)
* Sun Jan 30 2011 mc@suse.de
- backport upstrem fixes
* Tue Jan 25 2011 mc@suse.de
- fix checksum handling.
* Sat Jan 22 2011 mc@suse.de
- fix macros
* Mon Jan 17 2011 mc@suse.de
- change suseServer ostarget to a foreign key to suseOSTarget(id)
* Thu Jan 13 2011 mc@suse.de
- Sending and receiving suse product profile data during
  client registration.
- subscribe channels according to submitted suse product data
* Tue Jan 11 2011 mc@suse.de
- reposync: search for credentials and add them to the URL
- fix signature handling
- reposync: find checksums for packages in channels with
  org_id null
* Wed Dec 15 2010 mc@suse.de
- fix KeyError while syncing repos (bnc#657064)
- skip patch instead of abort if no checksum for a package
  was found
* Thu Sep 16 2010 mantel@suse.de
- reflect rename of config files (/etc/rhn/default/rhn_server*conf)
* Wed Sep 15 2010 mantel@suse.de
- Initial release of spacewalk-backend
